window.Gleam.initSearch([{"doc":"radiate","title":"radiate","content":"# radiate\n\n[![Package Version](https://img.shields.io/hexpm/v/radiate)](https://hex.pm/packages/radiate)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/radiate/)\n\nHot reloading while in development for Gleam!\n\n## Introduction\n\nRadiate will watch any directory you specify for changes. When a file is\nchanged in that directory, it&#39;ll check if it&#39;s a Gleam file, and if it is, the\nproject will be recompiled and all modified modules will be reloaded, without\nhaving to restart the BEAM VM.\n\n## Quick start\n\n```gleam\n// On main.gleam\nimport gleam/erlang/process\nimport gleam/io\nimport radiate\nimport message\n\npub fn main() {\n  let _ =\n    radiate.new()\n    |&gt; radiate.add_dir(&quot;src&quot;)\n    |&gt; radiate.start()\n\n  let timer_subject = process.new_subject()\n\n  print_every_second(timer_subject)\n}\n\nfn print_every_second(subject: process.Subject(Nil)) {\n  process.send_after(subject, 1000, Nil)\n\n  let _ = process.receive(subject, 1500)\n  io.println(message.get_message())\n\n  print_every_second(subject)\n}\n\n// On message.gleam\npub fn get_message() -&gt; String {\n  &quot;Hello!&quot;\n}\n```\n\nWhen you first run this, it&#39;ll print &quot;Hello!&quot; every second.\n\nNow, go ahead and change the text `get_message` returns to `&quot;Hello, world!&quot;`, and save the file.\n\nAs soon as you save, the message printed is changed to &quot;Hello, world!&quot;, without needing to restart the program!\n\n### Warning for macOS users\n\nRight now, the `add_dir` function only supports `&quot;.&quot;` or an absolute path! Be careful to resolve the path to get it work if you want to watch `&quot;src&quot;` for example.\n\n## Adding a callback\n\nYou can add callbacks to be run every time code is reloaded through `on_reload`:\n\n```gleam\nimport radiate\nimport gleam/io\n\npub fn main() {\n  let _ = radiate.new()\n    |&gt; radiate.add_dir(&quot;src&quot;)\n    |&gt; radiate.on_reload(fn (_state, path) {\n      io.println(&quot;Change in &quot; &lt;&gt; path &lt;&gt; &quot;, reloading!&quot;)\n    })\n    |&gt; radiate.start()\n}\n```\n\n\n## Installation\n\nThis package can be added to your Gleam project:\n\n```sh\ngleam add radiate\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/radiate&gt;.\n","url":"index.html"},{"doc":"radiate","title":"Builder","content":"pub opaque type Builder(\n  state,\n  has_dirs,\n  has_initializer,\n  has_callback,\n)\n Opaque builder type for reloader. Create with `new`.\n\nSynonyms:\nradiate.Builder\nradiate Builder","url":"radiate.html#Builder"},{"doc":"radiate","title":"HasCallback","content":"pub type HasCallback\n Phantom type to indicate builder has callback\n\nSynonyms:\nradiate.HasCallback\nradiate HasCallback","url":"radiate.html#HasCallback"},{"doc":"radiate","title":"HasDirectories","content":"pub type HasDirectories\n Phantom type to indicate directories have been added\n\nSynonyms:\nradiate.HasDirectories\nradiate HasDirectories","url":"radiate.html#HasDirectories"},{"doc":"radiate","title":"HasInitializer","content":"pub type HasInitializer\n Phantom type to indicate builder has initializer\n\nSynonyms:\nradiate.HasInitializer\nradiate HasInitializer","url":"radiate.html#HasInitializer"},{"doc":"radiate","title":"NoCallback","content":"pub type NoCallback\n Phantom type to indicate builder has no callback\n\nSynonyms:\nradiate.NoCallback\nradiate NoCallback","url":"radiate.html#NoCallback"},{"doc":"radiate","title":"NoDirectories","content":"pub type NoDirectories\n Phantom type to indicate no directories are added\n\nSynonyms:\nradiate.NoDirectories\nradiate NoDirectories","url":"radiate.html#NoDirectories"},{"doc":"radiate","title":"NoInitializer","content":"pub type NoInitializer\n Phantom type to indicate builder has no initializer\n\nSynonyms:\nradiate.NoInitializer\nradiate NoInitializer","url":"radiate.html#NoInitializer"},{"doc":"radiate","title":"add_dir","content":"pub fn add_dir(\n  builder: Builder(a, b, c, d),\n  dir: String,\n) -&gt; Builder(a, HasDirectories, c, d)\n Add a directory to watch. The path can be relative or absolute.\n macOS users: always use `&quot;.&quot;` or an absolute path, otherwise it won&#39;t work\n properly!\nSynonyms:\nradiate.add_dir\nradiate add_dir","url":"radiate.html#add_dir"},{"doc":"radiate","title":"new","content":"pub fn new() -&gt; Builder(\n  Nil,\n  NoDirectories,\n  NoInitializer,\n  NoCallback,\n)\n Construct a new builder\nSynonyms:\nradiate.new\nradiate new","url":"radiate.html#new"},{"doc":"radiate","title":"on_reload","content":"pub fn on_reload(\n  builder: Builder(a, b, c, NoCallback),\n  callback: fn(a, String) -&gt; a,\n) -&gt; Builder(a, b, c, HasCallback)\n Add a callback to be run after reload\nSynonyms:\nradiate.on_reload\nradiate on_reload","url":"radiate.html#on_reload"},{"doc":"radiate","title":"set_initializer","content":"pub fn set_initializer(\n  builder: Builder(a, b, NoInitializer, c),\n  initializer: fn() -&gt; a,\n) -&gt; Builder(a, b, HasInitializer, c)\n Add an initializer\n\n This will be run in the file watcher process, so it can be useful to, for\n example, add state to an actor\nSynonyms:\nradiate.set_initializer\nradiate set_initializer","url":"radiate.html#set_initializer"},{"doc":"radiate","title":"start","content":"pub fn start(\n  builder: Builder(Nil, HasDirectories, NoInitializer, a),\n) -&gt; Result(Subject(Change(Nil)), StartError)\n Start reloader, if no state has been set\nSynonyms:\nradiate.start\nradiate start","url":"radiate.html#start"},{"doc":"radiate","title":"start_state","content":"pub fn start_state(\n  builder: Builder(a, HasDirectories, HasInitializer, b),\n) -&gt; Result(Subject(Change(Nil)), StartError)\n Start reloader, ensuring that a state has been set\nSynonyms:\nradiate.start_state\nradiate start_state","url":"radiate.html#start_state"},{"doc":"radiate","title":"radiate","content":"","url":"radiate.html"}]);